package com.pj.project.tb_person_filing;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.IdcardUtil;
import cn.hutool.core.util.PhoneUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;

import com.pj.current.global.BusinessException;
import com.pj.current.satoken.StpUserUtil;
import com.pj.project.tb_dept.TbDept;
import com.pj.project.tb_dept.TbDeptService;
import com.pj.utils.sg.AjaxError;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Component
public class ImportPersonListener extends AnalysisEventListener<ImportPersonBO> {
    @Resource
    @Lazy
    private TbPersonFilingService tbPersonFilingService;

    @Resource
    private TbDeptService tbDeptService;


    public List<ImportPersonBO> list = new ArrayList<>();

    @Override
    public void invoke(ImportPersonBO importPersonBO, AnalysisContext analysisContext) {
        if (StrUtil.isNotEmpty(importPersonBO.getDeptName())) {
            list.add(importPersonBO);
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext analysisContext) {
        int index = 1;
        List<TbPersonFiling>personFilings=new ArrayList<>();
        for (ImportPersonBO importPersonBO : list) {
            String deptName = importPersonBO.getDeptName();
            String name = importPersonBO.getName();
            if (StrUtil.isEmpty(name)) {
                throw new AjaxError("第" + index + "行姓名不能为空");
            }
            String phone = importPersonBO.getPhone();
            if (!PhoneUtil.isPhone(phone)) {
                throw new AjaxError("第" + index + "行手机号码不正确");
            }
            String idCard = importPersonBO.getIdCard();
            if (!IdcardUtil.isValidCard(idCard)) {
                throw new AjaxError("第" + index + "行身份证号不正确");
            }
            TbDept tbDept = tbDeptService.findByName(deptName);
            if (tbDept == null) {
                throw new AjaxError("组织不存在");
            }
            TbPersonFiling tbPersonFiling = tbPersonFilingService.findByIdCard(idCard);
            if (tbPersonFiling == null) {
                tbPersonFiling = new TbPersonFiling();
                tbPersonFiling.setCreateTime(new Date()).setCreateBy(StpUserUtil.getAdminName()).setUpdateTime(new Date());
            }
            if (TbDept.NeedJudgeEnum.AUTO_JUDGE.getType().equals(tbDept.getNeedJudge())) {
                tbPersonFiling.setJudgeState(1)
                        .setJudgeTime(new Date())
                        .setJudgeBy("平台自动审核");
            }
            tbPersonFiling.setType(importPersonBO.getType().equals("内部") ? 2 : 1).setName(name)
            .setPhone(phone).setPin(idCard).setIdCard(idCard).setDeptId(tbDept.getId())
            .setDeptName(tbDept.getName());
            personFilings.add(tbPersonFiling);
            index++;
        }
        tbPersonFilingService.saveOrUpdateBatch(personFilings);
    }
}
